@@ -25,7 +25,7 @@ class Bambuser(Service, OpenGraphThumbMixin):
             return
 
         json_url = "http://player-c.api.bambuser.com/getVideo.json?api_key=005f64509e19a868399060af746a00aa&vid=%s" % match.group(1)
-        data = self.http.request("get", json_url).content
+        data = self.http.request("get", json_url).text
 
         info = json.loads(data)["result"]
         video = info["url"]
